@@ -298,6 +298,19 @@ class EntityMixin:
     def get_vshard(self) -> int:
         raise NotImplementedError
 
+    def pp(self):
+        """Pretty-print entity attributes."""
+        cls = type(self)
+        field_names = []
+        for field in dir(cls):
+            if field.startswith("_"):
+                continue
+            if hasattr(getattr(cls, field), "type"):
+                field_names.append(field)
+        max_length = max(len(field_name) for field_name in field_names)
+        for field_name in field_names:
+            print(field_name.ljust(max_length), ":", getattr(self, field_name))
+
 
 VT = TypeVar("VT", bound="VertexMixin")
 
